==> wt-0.04.tar.gz: wt-0.04/wt.h <==
/*
**  wt -- a 3d game engine
**
**  Copyright (C) 1994 by Chris Laurel
**  email:  claurel@mr.net
**  snail mail:  Chris Laurel, 5700 W Lake St #208,  St. Louis Park, MN  55416
**
**  This program is free software; you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation; either version 2 of the License, or
**  (at your option) any later version.
**
**  This program is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with this program; if not, write to the Free Software
**  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

/* directory and file configuration */
#define TEXTURE_PATH "textures"
#define DEFAULT_WORLD_FILE "test.world"
#define DEFAULT_PALETTE_FILE "wt.pal"

#ifndef MIN
#define MIN(a, b) ((a) < (b) ? (a) : (b))
#endif
#ifndef MAX
#define MAX(a, b) ((a) > (b) ? (a) : (b))
#endif

#ifndef False
typedef enum { False, True } Boolean;
#else
#ifndef Boolean
#define Boolean int
#endif
#endif

#ifndef __GNUC__
#define inline
#endif

/* For compilers without NULL defined in stdlib.h */
#ifndef NULL
#include <stdio.h>
#endif

/* More compatibility stuff . . . */
#ifndef PATH_MAX
#ifdef _POSIX_PATH_MAX
#define PATH_MAX _POSIX_PATH_MAX
#else
#define PATH_MAX 1024
#endif
#endif

#ifndef EXIT_FAILURE
#define EXIT_FAILURE 1
#endif
#ifndef EXIT_SUCCESS
#define EXIT_SUCCES 0
#endif

==> wt-0.05.tar.gz: wt-0.05/wt.h <==
/*
**  wt -- a 3d game engine
**
**  Copyright (C) 1994 by Chris Laurel
**  email:  claurel@mr.net
**  snail mail:  Chris Laurel, 5700 W Lake St #208,  St. Louis Park, MN  55416
**
**  This program is free software; you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation; either version 2 of the License, or
**  (at your option) any later version.
**
**  This program is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with this program; if not, write to the Free Software
**  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

/* directory and file configuration */
#define TEXTURE_PATH "textures"
#define DEFAULT_WORLD_FILE "test.world"
#define DEFAULT_PALETTE_FILE "wt.pal"


#ifndef MIN
#define MIN(a, b) ((a) < (b) ? (a) : (b))
#endif
#ifndef MAX
#define MAX(a, b) ((a) > (b) ? (a) : (b))
#endif


#ifdef ARCH_MAC

#ifndef False
enum { False, True };
#endif

#ifndef Boolean
typedef unsigned char Boolean;
#endif

/* MBW - Another Mac name conflict solved.  Just don't include
        this _before_ any MacOS headers!
*/
#define Region wt_Region

#else

#ifndef False
typedef enum { False, True } Boolean;
#else
#ifndef Boolean
#define Boolean int
#endif
#endif

#endif /* MAC */


#ifndef __GNUC__
#define inline
#endif

/* For compilers without NULL defined in stdlib.h */
#ifndef NULL
#include <stdio.h>
#endif

/* More compatibility stuff . . . */
#ifndef PATH_MAX
#ifdef _POSIX_PATH_MAX
#define PATH_MAX _POSIX_PATH_MAX
#else
#define PATH_MAX 1024
#endif
#endif

#ifndef EXIT_FAILURE
#define EXIT_FAILURE 1
#endif
#ifndef EXIT_SUCCESS
#define EXIT_SUCCESS 0
#endif

#ifdef ARCH_SUN
#define memmove(a, b, c) bcopy(b, a, c)
#endif

/* The following types are needed by the drawing functions, where the exact
**   number of bits in a pixel is important.
*/
typedef unsigned char  int8;
typedef unsigned short int16;
